 /*
 * file      : configuser.c
 * project   : BaseBuild
 * with      : Gtk-2
 *
 * copyright : (C) 2010 by Claude Bulin
 *
 * BaseBuild - Creation d'une base de programmation en langage C de type GNU avec les autotools
 * GNU General Public License
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * OLD ADRESS:
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * NEW ADRESS:
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 * 
 */


#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#ifdef ENABLE_NLS
	#include <libintl.h>
	#define _(String) gettext (String)
#endif

#include <gtk/gtk.h>

#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>
#include <unistd.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <stdlib.h>

#include "../libbasebuild/libbasebuild.h"
#include "global.h"
#include "configuser.h"



VAR_CONFIG Config = {
	FALSE,		// BoolConfigOk
	NULL,		// Path
	NULL,		// NameProject
	0,		// WinPos_X
	0,		// WinPos_Y
	750,		// WinWidth
	680,		// WinHeight
	0		// Page

};


// RETOURNE LE NOM COMPLET DU FICHIER DE CONFIGURATION
// 
gchar *config_get_pathname (void)
{
	return ((gchar *)g_strdup_printf ("%s/%s", getenv ("HOME"), ".config/basebuild/basebuild.conf"));
}
// RETOURNE UNE DEFINITION DU FICHIER DE CONFIGURATION
// 
gchar *config_get_target (gchar *p_buf)
{
	gchar	*Str = NULL;
	gchar	*Ptr = NULL;
	
	if ((Ptr = strchr (p_buf, '=')) != NULL) {
		Ptr ++;
		while (*Ptr && (*Ptr != ' ' && *Ptr != '\t')) Ptr ++;
		Ptr ++;
		Str = g_strdup (Ptr);
		if ((Ptr = strchr (Str, '\r')) != NULL) *Ptr = '\0';
		if ((Ptr = strchr (Str, '\n')) != NULL) *Ptr = '\0';
	}
	return ((gchar *)Str);
}
// LECTURE DU FICHIER DE CONFIGURATION
// 
void config_read (void)
{
	gchar	*PathNameConfig = config_get_pathname ();
	FILE	*fp;
#define MAX_CARS 255
	gchar	 buf   [ MAX_CARS +1 ];
	gchar	*Ptr = NULL;
	
	if (libutils_test_file_exist (PathNameConfig) == FALSE) {
		
		gchar	*StrDir = g_strdup (PathNameConfig);
		gchar	*Ptr = strrchr (StrDir, '/');
		
		Ptr ++;
		*Ptr = '\0';
		g_mkdir_with_parents (StrDir, 0700);
		g_free (StrDir);
		StrDir = Ptr = NULL;
		
		config_save ();
	}
	
	fp = fopen (PathNameConfig, "r");
	while (fgets (buf, MAX_CARS, fp) != NULL) {
		
		// Si commentaire ou ligne vide alors ligne suivante
		if (buf[0] == '#' || buf[0] == '\n') continue;

		if (libutils_new_strcmp (buf, "PATH") == TRUE) {
			if ((Ptr = config_get_target (buf)) != NULL) {
				if (libutils_test_dir_exist (Ptr) == TRUE) {
					Config.Path = Ptr;
				} else {
					Config.Path = getenv ("HOME");
					g_free (Ptr);
					Ptr = NULL;
				}
			}
		}
		else if (libutils_new_strcmp (buf, "NAME_PROJECT") == TRUE) {
			if ((Ptr = config_get_target (buf)) != NULL) {
				Config.NameProject = g_strdup (Ptr);
				g_free (Ptr);
				Ptr = NULL;
			}
		}
		else if (libutils_new_strcmp (buf, "WIN_POS_X") == TRUE) {
			if ((Ptr = config_get_target (buf)) != NULL) {
				Config.WinPos_X = atoi (Ptr);
				// g_print("Config.WinPos_X = Ptr = %s\n", Ptr);
				g_free (Ptr);
				Ptr = NULL;
			}
		}
		else if (libutils_new_strcmp (buf, "WIN_POS_Y") == TRUE) {
			if ((Ptr = config_get_target (buf)) != NULL) {
				Config.WinPos_Y = atoi (Ptr);
				// g_print("Config.WinPos_Y = Ptr = %s\n", Ptr);
				g_free (Ptr);
				Ptr = NULL;
			}
		}
		else if (libutils_new_strcmp (buf, "WIN_WIDTH") == TRUE) {
			if ((Ptr = config_get_target (buf)) != NULL) {
				Config.WinWidth = atoi (Ptr);
				// g_print("Config.WinWidth = Ptr = %s\n", Ptr);
				g_free (Ptr);
				Ptr = NULL;
			}
		}
		else if (libutils_new_strcmp (buf, "WIN_HEIGHT") == TRUE) {
			if ((Ptr = config_get_target (buf)) != NULL) {
				Config.WinHeight = atoi (Ptr);
				// g_print("Config.WinHeight = Ptr = %s\n", Ptr);
				g_free (Ptr);
				Ptr = NULL;
			}
		}
		else if (libutils_new_strcmp (buf, "PAGE_NOTEBOOK") == TRUE) {
			if ((Ptr = config_get_target (buf)) != NULL) {
				Config.Page = atoi (Ptr);
				// g_print("Config.WinHeight = Ptr = %s\n", Ptr);
				g_free (Ptr);
				Ptr = NULL;
			}
		}
		
		buf [ 0 ] = '\0';
	}
	fclose (fp);
}
//  SAUVEGARDE DU FICHIER DE CONFIGURATION
// 
void config_save (void)
{
	gchar	*PathNameConfig = config_get_pathname ();
	FILE	*fp;
	
	if (NULL != (fp = fopen (PathNameConfig, "w"))) {
		fprintf (fp,   "############################################################################\n");
		fprintf (fp,   "## Fichier de configuration pour : %s\n", PACKAGE_STRING);
		fprintf (fp,   "##--------------------------------------------------------------------------\n");
		fprintf (fp,   "## File of configuration to : %s\n", PACKAGE_STRING);
		fprintf (fp,   "############################################################################\n");
		
		fprintf (fp, "\n");
		fprintf (fp, "PATH             = %s\n", Config.Path == NULL ? getenv ("HOME") : Config.Path);
		fprintf (fp, "NAME_PROJECT     = %s\n", Config.NameProject == NULL ? "NameProject" : Config.NameProject);
		fprintf (fp, "WIN_POS_X        = %d\n", Config.WinPos_X);
		fprintf (fp, "WIN_POS_Y        = %d\n", Config.WinPos_Y);
		fprintf (fp, "WIN_WIDTH        = %d\n", Config.WinWidth);
		fprintf (fp, "WIN_HEIGHT       = %d\n", Config.WinHeight);
		fprintf (fp, "PAGE_NOTEBOOK    = %d\n", Config.Page);
		fprintf (fp, "\n");
		fclose (fp);
	}
}
// LIBERATION MEMOIRE
// 
void config_remove (void)
{
	g_free (Config.Path);
	Config.Path = NULL;
	g_free (Config.NameProject);
	Config.NameProject = NULL;
}































